// java wrapper for vtkDatabaseToTableReader object
//

package vtk;
import vtk.*;

public class vtkDatabaseToTableReader extends vtkTableAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native boolean SetDatabase_2(vtkSQLDatabase id0);
  public boolean SetDatabase(vtkSQLDatabase id0)
    { return SetDatabase_2(id0); }

  private native boolean SetTableName_3(String id0);
  public boolean SetTableName(String id0)
    { return SetTableName_3(id0); }

  private native boolean CheckIfTableExists_4();
  public boolean CheckIfTableExists()
    { return CheckIfTableExists_4(); }

  private native long GetDatabase_5();
  public vtkSQLDatabase GetDatabase() {
    long temp = GetDatabase_5();

    if (temp == 0) return null;
    return (vtkSQLDatabase)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkDatabaseToTableReader() { super(); }

  public vtkDatabaseToTableReader(long id) { super(id); }

}
